==Biblioteca geradora de cmpkg==

This library allows the generation of Colibri Master Packages, also known as extensions CMPKG.

===Main versions released ==

2.2.0.1

- Support only for Python 3.11 or above.

2.0.0.1

- Support removed for super "packages";
- Provide errors when executables doesn't meet certain patterns.

1.0.2.0

- Encoding fixed.

1.0.0.0

- Support to embed multiple database scripts sets.
